import { useEffect, useRef, useState } from 'react';

const AnimatedBackground = ({ children }) => {
    const containerRef = useRef(null);
    const [linePaths, setLinePaths] = useState([]);

    useEffect(() => {
        const updatePaths = () => {
            if (containerRef.current) {
                const box = containerRef.current.getBoundingClientRect();
                const width = box.width;
                const height = box.height;

                // Calculate starting points and angles for parallel lines
                const startX = width * 0;  // Start from right side
                const startY = height * 0.9; // Start from bottom
                const endX = width * 1.2;    // End at 30% of width
                const endY = height * -0.3;   // End at 30% of height
                const spacing = 80;          // 2em spacing between lines

                // Calculate angle and offsets
                const angle = Math.atan2(startY - endY, startX - endX);
                const xOffset = spacing * Math.sin(angle);
                const yOffset = spacing * Math.cos(angle);

                // Create 5 parallel lines
                const paths = Array.from({ length: 7 }).map((_, index) => {
                    const startXOffset = index * xOffset;
                    const startYOffset = index * yOffset;

                    return `M ${startX - startXOffset} ${startY - startYOffset} 
                            L ${endX - startXOffset} ${endY - startYOffset}`;
                });

                setLinePaths(paths);
            }
        };

        updatePaths();
        window.addEventListener('resize', updatePaths);
        return () => window.removeEventListener('resize', updatePaths);
    }, []);

    return (
        <div ref={containerRef} className="position-relative min-vh-100">

            {/* Animated lines */}
            <div className="position-absolute w-100 h-100">
                <svg className="w-100 h-100">
                    {linePaths.map((path, index) => (
                        <g key={index}>
                            {/* Background line */}
                            {/* Animated border */}
                            <path
                                d={path}
                                fill="none"
                                stroke={`${index % 2 === 0 ? 'rgba(179, 80, 224, 0.4)' : 'rgba(150, 50, 190, .2)'}`}
                                strokeWidth="2"
                                strokeLinecap="round"
                                strokeDasharray="40 240"
                                style={{
                                    animation: `dash ${0.4 * index + 20}s linear infinite`,
                                }}
                            />
                        </g>
                    ))}
                </svg>
            </div>

            {/* Content container */}
            <div className="position-relative" style={{ zIndex: 10 }}>
                {children}
            </div>

            <style>
                {`
                    @keyframes dash {
                        from {
                            stroke-dashoffset: 280;
                        }
                        to {
                            stroke-dashoffset: -280;
                        }
                    }

                `}
            </style>
        </div>
    );
};

export default AnimatedBackground;