import { BasicProp } from "@shared/types/interfaces.type";
import React, { createContext, useContext, useMemo } from "react";
import { useTranslation } from "react-i18next";
import { toast } from "react-toastify";

interface UtilsProviderType {
    toClipboard: (text: string) => void
}

const UtilsContext = createContext<UtilsProviderType>({
    toClipboard: function (): void {
        throw new Error("Function not implemented.");
    }
})

export const UtilsProvider: React.FC<BasicProp> = ({ children }) => {
    const { t } = useTranslation('common');

    const value = useMemo<UtilsProviderType>(() => {
        return {
            toClipboard(text) {
                navigator.clipboard.writeText(text);
                toast.info(t('global.toast.copied'))
            },
        } as UtilsProviderType
    }, [t])

    return (
        <UtilsContext.Provider value={value}>
            {children}
        </UtilsContext.Provider>
    )
}

export const useUtils = () => {
    return useContext(UtilsContext)
}